# UniMatch

## Original code

[https://github.com/autonomousvision/unimatch](https://github.com/autonomousvision/unimatch)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@article{xu2022unifying,
  title={Unifying Flow, Stereo and Depth Estimation},
  author={Xu, Haofei and Zhang, Jing and Cai, Jianfei and Rezatofighi, Hamid and Yu, Fisher and Tao, Dacheng and Geiger, Andreas},
  journal={arXiv preprint arXiv:2211.05783},
  year={2022}
}
```